@@ -1,8 +1,10 @@
 import click
 
+
 class EmptyFileError(Exception):
     pass
 
+
 class TTYError(click.ClickException):
     def __init__(self, message: str) -> None:
-        super().__init__('Could not read from stdin: ' + message)
\ No newline at end of file
+        super().__init__("Could not read from stdin: " + message)
